@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Net::MQTT::Message::Connect;
 BEGIN {
-  $Net::MQTT::Message::Connect::VERSION = '1.110160';
+  $Net::MQTT::Message::Connect::VERSION = '1.110170';
 }
 
 # ABSTRACT: Perl module to represent an MQTT Connect message
@@ -43,7 +43,10 @@ sub will_qos { shift->{will_qos} || 0 }
 sub will_flag { shift->{will_flag} || 0 }
 
 
-sub clean_session { shift->{clean_session} || 1 }
+sub clean_session {
+  my $self = shift;
+  defined $self->{clean_session} ? $self->{clean_session} : 1
+}
 
 
 sub connect_reserved_flag { shift->{connect_reserved_flag} || 0 }
@@ -132,7 +135,7 @@ Net::MQTT::Message::Connect - Perl module to represent an MQTT Connect message
 
 =head1 VERSION
 
-version 1.110160
+version 1.110170
 
 =head1 SYNOPSIS
 
